@@ -162,7 +162,7 @@ proctable_new (ProcData *data)
 	gtk_tree_view_column_set_attributes (column, cell_renderer,
 					     "text", COL_NAME,
 					     NULL);
-	gtk_tree_view_column_set_title (column, title[0]);
+	gtk_tree_view_column_set_title (column, _(title[0]));
 	gtk_tree_view_column_set_sort_column_id (column, COL_NAME);
 	gtk_tree_view_column_set_resizable (column, TRUE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (proctree), column);
@@ -170,7 +170,7 @@ proctable_new (ProcData *data)
   	
   	for (i = 1; i < NUM_COLUMNS - 2; i++) {
   		cell_renderer = gtk_cell_renderer_text_new ();
-  		column = gtk_tree_view_column_new_with_attributes (title[i],
+  		column = gtk_tree_view_column_new_with_attributes (_(title[i]),
 						    		   cell_renderer,
 						     		   "text", i,
 						     		   NULL);
@@ -253,7 +253,7 @@ proctable_free_info (ProcInfo *info)
 	if (info->status)
 		g_free (info->status);
 	if (info->pixbuf)
-		gdk_pixbuf_unref (info->pixbuf);
+		g_object_unref (info->pixbuf);
 	g_free (info);
 }
 
@@ -483,6 +483,8 @@ remove_children_from_tree (ProcData *procdata, GtkTreeModel *model,
 		
 		gtk_tree_model_get (model, parent, COL_POINTER, &child_info, -1);
 		if (child_info) {
+			if (procdata->selected_process == child_info) 
+				procdata->selected_process = NULL;
 			procdata->info = g_list_remove (procdata->info, child_info);
 			proctable_free_info (child_info);
 		}
@@ -496,7 +498,6 @@ remove_info_from_tree (ProcInfo *info, ProcData *procdata)
 	GtkTreeModel *model;
 	GtkTreeIter iter, child;
 	GtkTreePath *node;
-	gboolean selected = FALSE;
 	
 	g_return_if_fail (info);
 	
@@ -511,16 +512,10 @@ remove_info_from_tree (ProcInfo *info, ProcData *procdata)
 		remove_children_from_tree (procdata, model, &child);
 	
 	if (procdata->selected_process == info) 
-		selected = TRUE;
+		procdata->selected_process = NULL;
 	
 	gtk_tree_store_remove (GTK_TREE_STORE (model), &iter);
 	
-	if (selected) {
-		node = gtk_tree_model_get_path (model, &iter);
-		gtk_tree_view_set_cursor (GTK_TREE_VIEW (procdata->tree), node, NULL, FALSE);
-		gtk_tree_path_free (node);
-	}
-	
 	info->visible = FALSE;	
 		
 }
@@ -576,11 +571,20 @@ update_info (ProcData *procdata, ProcInfo *info, gint pid)
 	}
 	
 	if (info->visible) {
+		GtkTreePath *path;
 		mem = get_size_string (info->mem);
 		vmsize = get_size_string (info->vmsize);
 		memres = get_size_string (info->memres);
 		memshared = get_size_string (info->memshared);
 		memrss = get_size_string (info->memrss);
+		/* This is a hack to catch an ugly bug */
+		path = gtk_tree_model_get_path (model, &info->node);
+		if (path == NULL) {
+			g_print ("damn error %s %d\n", info->name, info->pid);
+			g_assert (0);
+			return;
+		}
+		gtk_tree_path_free (path);
 		gtk_tree_store_set (GTK_TREE_STORE (model), &info->node, 
 				    COL_STATUS, info->status,
 				    COL_MEM, mem,
